/*
 *    QueryHistoryModel.java
 *    Copyright (C) 2001 New Zealand Digital Library Project
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


package org.nzdl.gsdl.SimpleGraphicalClient;

import java.util.*;
import javax.swing.event.*;
import javax.swing.*;
import javax.swing.table.*;

class QueryHistoryModel extends AbstractTableModel implements Constants {

    private ArrayList historyItems; 
    private ArrayList columnTitles;

    private String COLLECTION = "Collection";
    private String DATE_TIME = "Time";
    private String TERMS = "Terms";
    private String HITS  = "Hits";
    private String QUERYTYPE = "Type";
    private String STEMMED = "Stem?";
    private String CASEMATCHED = "Case?";


    public QueryHistoryModel() {
	super();
	historyItems = new ArrayList();
	columnTitles = new ArrayList();
	columnTitles.add( DATE_TIME);
	columnTitles.add( COLLECTION);
	columnTitles.add( TERMS);
	columnTitles.add(QUERYTYPE);
	columnTitles.add(STEMMED);
	columnTitles.add(CASEMATCHED);
	columnTitles.add( HITS);
    }

	
    public void add(QueryHistoryItem queryHistoryItem) {
	historyItems.add(0,queryHistoryItem); //add at the top!
	//fireTableDataChanged(); //too general
	fireTableRowsInserted(0,0);
    }
	
    public int getColumnCount() {
	return columnTitles.size();
    }

    public Class getColumnClass(int c) {
	return getValueAt(0, c).getClass();
    }

    public int getRowCount() {
	return historyItems.size();
    }

    public String getColumnName(int column) {
	return (String) columnTitles.get(column);
    }

    public Object getValueAt( int row, int column ) {
	QueryHistoryItem historyItem = (QueryHistoryItem)historyItems.get(row);
	if (column == columnTitles.indexOf(DATE_TIME)) return historyItem.getDate();
	if (column == columnTitles.indexOf(COLLECTION)) return new CollectionName(historyItem.getCollectionName());
	if (column == columnTitles.indexOf(TERMS)) return new Query(historyItem.getQuery().toString());
	if (column == columnTitles.indexOf(HITS)) return new Long(historyItem.getNumOfHits());
	if (column == columnTitles.indexOf(QUERYTYPE)) return new String(historyItem.getQueryType());
	if (column == columnTitles.indexOf(STEMMED)) return new Boolean(historyItem.getStemmed());
	if (column == columnTitles.indexOf(CASEMATCHED)) return new Boolean( historyItem.getCaseMatched());

	// something has gone wrong if we get here!
	// but display something anyway...
	return "row" + row + "col" + column;
    }
   


    public class CollectionName extends Object {
	String string;

	CollectionName(String newString) {
	    string = newString;
	}

	public String toString() {
	    return string;
	}

    } // CollectionName


} //QueryHistoryModel
